geowatch.tasks.landcover package
================================

Submodules
----------

.. toctree::
   :maxdepth: 4

   geowatch.tasks.landcover.datasets
   geowatch.tasks.landcover.detector
   geowatch.tasks.landcover.fit
   geowatch.tasks.landcover.model_info
   geowatch.tasks.landcover.nets
   geowatch.tasks.landcover.predict
   geowatch.tasks.landcover.utils

Module contents
---------------

.. automodule:: geowatch.tasks.landcover
   :members:
   :undoc-members:
   :show-inheritance:
